@@ -1,9 +1,9 @@
 import os
 import json
-from .tools import default_config, write_config, set_plink
-from .geno_tools import delete_tmp
+from .tools import default_config, write_config, set_plink, delete_tmp
+from .geno_tools import Combine_Geno
 
-__version__ = "0.1"
+__version__ = "0.3"
 
 config_dir = os.path.expanduser(
     "~/.genal/"
